@@ -12,7 +12,7 @@
  * General Public License for more details.
  */
 
-#pragma ident "@(#)msg.c	1.2	04/07/09 meem"
+#pragma ident "@(#)msg.c	1.3	04/09/07 meem"
 
 #include <string.h>
 #include <stdio.h>
@@ -168,9 +168,24 @@ msg(rlpr_msg_level_e level, int errno, const char *format, ...)
 	} else {
 	    format = _(format);
 	}
-	
-	vsyslog(rlpr_msg->syslog_prio[level], format, ap);
 
+#ifdef HAVE_VSYSLOG
+	vsyslog(rlpr_msg->syslog_prio[level], buf, ap);
+#else
+	{
+	    char *a1 = va_arg(ap, char *);
+	    char *a2 = va_arg(ap, char *);
+	    char *a3 = va_arg(ap, char *);
+	    char *a4 = va_arg(ap, char *);
+	    char *a5 = va_arg(ap, char *);
+	    char *a6 = va_arg(ap, char *);
+	    char *a7 = va_arg(ap, char *);
+	    char *a8 = va_arg(ap, char *);
+
+	    syslog(rlpr_msg->syslog_prio[level], buf, a1, a2, a3, a4, a5, a6,
+		a7, a8);
+	}
+#endif
     } else {
 
 	fprintf(stream, "%s: ", program_name);
